@@ -8,7 +8,7 @@
 #include "../config/DBBalancerConfig.hh"
 
 
-// Constructor: Copy the attributes, and init the backend connections.
+// Copy the attributes, and init the frontend and backend connections.
 
 DBPostgresWriterConnection::DBPostgresWriterConnection(DBBalancerConfig *config, vector<DBHostConfig *> hosts, string id) {
 
@@ -60,6 +60,8 @@ DBPostgresWriterConnection::DBPostgresWriterConnection(DBBalancerConfig *config,
 
 DBPostgresWriterConnection::~DBPostgresWriterConnection() {
 
+  ACE_DEBUG((LM_DEBUG,"(%t,%T) Destroying DBPostgresWriterConnection(): %s.\n",this->getId().c_str()));
+
   // Delete the connections.
   for (unsigned int i=0; i<_be.size();i++) {
 
@@ -85,7 +87,7 @@ bool DBPostgresWriterConnection::handleConnection(int fe_socket) {
   int loop_iterations;
   unsigned int discarded_reads;
   
-  ACE_DEBUG((LM_INFO,"(%t, %T) (%s) Handling connection.\n",getId().c_str()));
+  ACE_DEBUG((LM_DEBUG,"(%t, %T) (%s) Handling connection.\n",getId().c_str()));
   ACE_DEBUG((LM_DEBUG,"(%t, %T) Processing new conection. Receiving login data. (socket: %d)\n",fe_socket));
 
   if (_fe->receiveStartup(fe_socket)) {
@@ -157,7 +159,7 @@ bool DBPostgresWriterConnection::handleConnection(int fe_socket) {
       if (FD_ISSET(fe_socket,&read_set)) {
 	
 	ACE_DEBUG((LM_DEBUG," (%t, %T) Data in FE socket.\n"));
-	// Reset the NEW COMMAND indicator
+	// Reset the NEW COMMAND indicator. Used to know if this chunk is the beggining or the middle of a command.
 	_new_command = true;
 
 	// Now we'll loop till we read all data in FE socket
@@ -562,9 +564,10 @@ bool DBPostgresWriterConnection::checkConnection() {
 	all_ok = false;
   }
   
-  if (all_ok)
+  if (all_ok) {
     ACE_DEBUG((LM_DEBUG,"(%t,%T) Connection  Valid\n"));
-else
+    _fe->setKey(_be[0]->getKeyPointer(),_be[0]->getKeySize());    
+  } else
     ACE_DEBUG((LM_DEBUG,"(%t,%T) Connection  inValid\n"));
 
 
